@@ -23,19 +23,19 @@
 //! | `dark` | string | The name of the profile to use in dark mode | (none) |
 //! | `light` | string | The name of the profile to use in light mode | (none) |
 
-use std::error::Error;
 use std::io::Write;
 use std::os::unix::net::UnixStream;
 
+use anyhow::{Context, Result};
 use log::trace;
-use serde::{Serialize, Deserialize};
+use serde::{Deserialize, Serialize};
 
-use crate::themeable::{ConfigError, ConfigState, Themeable};
-use crate::operation::Operation;
 use crate::config::Config as ThconConfig;
+use crate::operation::Operation;
 use crate::sockets;
-use crate::Disableable;
+use crate::themeable::{ConfigError, ConfigState, Themeable};
 use crate::AppConfig;
+use crate::Disableable;
 
 #[derive(Debug, Deserialize, Disableable, AppConfig)]
 pub struct _Config {
@@ -47,7 +47,7 @@ pub struct _Config {
 
 #[derive(Debug, Serialize)]
 pub struct WireConfig {
-    profile: String
+    profile: String,
 }
 
 pub struct Iterm2;
@@ -56,9 +56,11 @@ impl Themeable for Iterm2 {
         ConfigState::with_manual_config(config.iterm2.as_ref().map(|c| c.inner.as_ref()))
     }
 
-    fn switch(&self, config: &ThconConfig, operation: &Operation) -> Result<(), Box<dyn Error>> {
+    fn switch(&self, config: &ThconConfig, operation: &Operation) -> Result<()> {
         let config = match self.config_state(config) {
-            ConfigState::NoDefault => return Err(Box::from(ConfigError::RequiresManualConfig("iterm2"))),
+            ConfigState::NoDefault => {
+                return Err(ConfigError::RequiresManualConfig("iterm2").into())
+            }
             ConfigState::Default => unreachable!(),
             ConfigState::Disabled => return Ok(()),
             ConfigState::Enabled => config.iterm2.as_ref().unwrap().unwrap_inner_left(),
@@ -66,16 +68,21 @@ impl Themeable for Iterm2 {
 
         let profile_name = match operation {
             Operation::Darken => &config.dark,
-            Operation::Lighten => &config.light
+            Operation::Lighten => &config.light,
+        };
+        let wire_format = WireConfig {
+            profile: profile_name.to_string(),
         };
-        let wire_format = WireConfig{ profile: profile_name.to_string() };
         let payload = serde_json::to_vec(&wire_format).unwrap_or_default();
 
         let addr = sockets::socket_addr("iterm2", false);
         if let Ok(mut stream) = UnixStream::connect(&addr) {
             trace!("Writing to socket at {}", &addr.display());
-            stream.write_all(&payload).unwrap_or(())
+            stream
+                .write_all(&payload)
+                .with_context(|| format!("Unable to write to scoket at {}", addr.display()))?;
         }
+
         Ok(())
     }
 }
