@@ -11,15 +11,16 @@
 //! | --- | ---- | ----------- | -------- |
 //! | `disabled` | boolean | `true` to disable theming of this app, otherwise `false` | `false` |
 
-use crate::themeable::{ConfigState, Themeable};
-use crate::operation::Operation;
 use crate::config::Config as ThconConfig;
-use crate::Disableable;
+use crate::operation::Operation;
+use crate::themeable::{ConfigState, Themeable};
 use crate::AppConfig;
+use crate::Disableable;
 
-use std::error::Error;
 use std::process::Command;
 
+use anyhow::anyhow;
+use anyhow::{Context, Result};
 use serde::Deserialize;
 
 #[derive(Debug, Deserialize, Disableable, AppConfig)]
@@ -35,7 +36,7 @@ impl Themeable for MacOS {
         ConfigState::with_default_config(config.macos.as_ref().map(|c| c.inner.as_ref()))
     }
 
-    fn switch(&self, config: &ThconConfig, operation: &Operation) -> Result<(), Box<dyn Error>> {
+    fn switch(&self, config: &ThconConfig, operation: &Operation) -> Result<()> {
         match self.config_state(config) {
             ConfigState::NoDefault => unreachable!(),
             ConfigState::Default => (),
@@ -51,13 +52,19 @@ impl Themeable for MacOS {
         Command::new("osascript")
             .arg("-e")
             .arg(format!(
-                    "tell app \"System Events\" to \
+                "tell app \"System Events\" to \
                      tell appearance preferences to \
                      set dark mode to {}",
-                     dark_mode
-            )).status()
-            .expect("Failed to execute `osascript`");
-
-        Ok(())
+                dark_mode
+            ))
+            .status()
+            .context("Failed to execute 'osascript'")
+            .and_then(|status| {
+                if status.success() {
+                    Ok(())
+                } else {
+                    Err(anyhow!("Failed to execute 'osascript'"))
+                }
+            })
     }
 }
